[Pkg-privacy-commits] [libotr] 84/225: Remove some compilation warnings from context.[ch]

Ximin Luo infinity0 at moszumanska.debian.org
Sat Aug 22 12:44:59 UTC 2015


This is an automated email from the git hooks/post-receive script.

infinity0 pushed a commit to branch master
in repository libotr.

commit c3301146d3987495ade28c614e33c5146a14039a
Author: Ian Goldberg <iang at cs.uwaterloo.ca>
Date:   Thu Jul 19 09:44:31 2012 -0400

    Remove some compilation warnings from context.[ch]
---
 src/context.c | 6 +++---
 src/context.h | 7 +++++--
 2 files changed, 8 insertions(+), 5 deletions(-)

diff --git a/src/context.c b/src/context.c
index d88c36a..96c191a 100644
--- a/src/context.c
+++ b/src/context.c
@@ -29,9 +29,6 @@
 #include "context.h"
 #include "instag.h"
 
-static void set_instance_fingerprint_next(OtrlUserState us,
-	ConnContext *context);
-
 /* Create a new connection context. */
 static ConnContext * new_context(const char * user, const char * accountname,
 	const char * protocol)
@@ -254,10 +251,13 @@ ConnContext * otrl_context_find(OtrlUserState us, const char *user,
     return NULL;
 }
 
+/* Return true iff the given fingerprint is marked as trusted. */
 int otrl_context_is_fingerprint_trusted(Fingerprint *fprint) {
     return fprint && fprint->trust && fprint->trust[0] != '\0';
 }
 
+/* This method gets called after sending or receiving a message, to
+ * update the master context's "recent context" pointers. */
 void otrl_context_update_recent_child(ConnContext *context,
 	unsigned int sent_msg) {
     ConnContext *m_context = context->m_context;
diff --git a/src/context.h b/src/context.h
index 9633fbc..4dfe236 100644
--- a/src/context.h
+++ b/src/context.h
@@ -141,8 +141,11 @@ ConnContext * otrl_context_find(OtrlUserState us, const char *user,
 	otrl_instag_t their_instance, int add_if_missing, int *addedp,
 	void (*add_app_data)(void *data, ConnContext *context), void *data);
 
-/* This method gets called after sending or receiving a message, to update the
- * master context's "recent context" pointers. */
+/* Return true iff the given fingerprint is marked as trusted. */
+int otrl_context_is_fingerprint_trusted(Fingerprint *fprint);
+
+/* This method gets called after sending or receiving a message, to
+ * update the master context's "recent context" pointers. */
 void otrl_context_update_recent_child(ConnContext *context,
 	unsigned int sent_msg);
 

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-privacy/packages/libotr.git



More information about the Pkg-privacy-commits mailing list